==> nextcloud-13.0.1.tgz: nextcloud/apps/survey_client/l10n/fi.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Käyttötutkimus",
    "Sent on: {on}" : "Lähetetty: {on}",
    "An error occurred while sending your report." : "Tapahtui virhe lähetettäessä raporttia.",
    "Database environment <em>(type, version, database size)</em>" : "Tietokantaympäristö <em>(tyyppi, versio, tietokannan koko)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Jakojen määrä <em>(tyyppi ja käyttöoikeusasetukset)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-ympäristö <em>(versio, muistin raja, maks. suoritusaika, maks. tiedostokoko)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Tilastotieto <em>(tiedostojen, käyttäjien, muistien, komenttien ja tunnisteiden määrä)</em>",
    "Help improve Nextcloud" : "Auta parantamaan Nextcloudia",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Haluatko auttaa meitä Nextcloudin kehittämisessä lähettämällä anonyymiä tietoa asetuksistasi ja käytöstäsi? Voit estää tietojen lähettämisen koska tahansa ylläpitoasetuksissa.",
    "Not now" : "Ei nyt",
    "Send usage" : "Lähetä käyttötiedot",
    "Never" : "Ei koskaan",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Voit auttaa Nextcloudin kehittämistä lähettämällä tietoja nykyisestä asennuksesta ja käytöstä.",
    "Send new report now" : "Lähetä uusi raportti nyt",
    "Send usage survey monthly" : "Lähetä käyttötutkimusraportti kuukausittain",
    "Data to send" : "Lähetettävät tiedot",
    "Last report" : "Edellinen raportti",
    "Sent on: %s" : "Lähetetty: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Sovelluslista <em>(jokaisesta sovelluksesta: nimi, versio, onko käytössä?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Palvelininstanssin ominaisuudet <em>(versio, memcache käytössä, lukitus/esikatselut/avatarit käytössä?)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Voit auttaa meitä Nextcloudin kehittämisessä lähettämällä meille tietoja nykyisestä asennuksesta ja käytöstä."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.5.tgz: nextcloud/apps/survey_client/l10n/fi.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Viimeisin raportti lähetetty: {on}",
    "An error occurred while sending your report." : "Tapahtui virhe lähetettäessä raporttia.",
    "Database environment <em>(type, version, database size)</em>" : "Tietokantaympäristö <em>(tyyppi, versio, tietokannan koko)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Jakojen määrä <em>(tyyppi ja käyttöoikeusasetukset)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-ympäristö <em>(versio, muistin raja, maks. suoritusaika, maks. tiedostokoko)</em>",
    "Usage survey" : "Käyttötutkimus",
    "Help improve Nextcloud" : "Auta parantamaan Nextcloudia",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Haluatko auttaa meitä Nextcloudin kehittämisessä lähettämällä anonyymiä tietoa asetuksistasi ja käytöstäsi? Voit estää tietojen lähettämisen koska tahansa ylläpitoasetuksissa.",
    "Not now" : "Ei nyt",
    "Send usage" : "Lähetä käyttötiedot",
    "Never" : "Ei koskaan",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Voit auttaa Nextcloudin kehittämistä lähettämällä tietoja nykyisestä asennuksesta ja käytöstä.",
    "Send new report now" : "Lähetä uusi raportti nyt",
    "Send usage survey monthly" : "Lähetä käyttötutkimusraportti kuukausittain",
    "Data to send" : "Lähetettävät tiedot",
    "Last report sent on: %s" : "Viimeisin raportti lähetetty: %s",
    "Last report" : "Edellinen raportti"
},
"nplurals=2; plural=(n != 1);");
